import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range(['#c11d1d', '#eae600']);

const radiusScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range([20, 10]);

const xPosition = (d, i) => i * 80 + 60;

export const fruitBowl = (selection, props) => {
  
  const { fruits, height } = props;
  // This is just the update selection.
  
  const bowl = selection.selectAll('rect')
  	.data([null])
  	.enter().append('rect')
  	.attr('y', 175)
  	.attr('width', 435)
  	.attr('height', 150)
  	.attr('rx', 75)
  
  // maps a unique identifier to the data join. 
  const groups = selection.selectAll('g')
  	.data(fruits, d => d.id); 
  
  const groupsEnter = groups.enter().append('g'); 
  
  groupsEnter
  // find where the elements in the enter selection
  	.attr('transform', (d, i) => `translate(${i * 80 + 60}, ${height/2})`)
    .merge(groups)
  // at the update selection, update the position of elements accordingly, and apply the transition
    .transition().duration(1000)
    	.attr('transform', (d, i) => `translate(${i * 80 + 60}, ${height/2})`);
  
  groupsEnter.append('circle')
  		// .attr('cx', xPosition)
  		// .attr('cy', height/2)
  	.attr('r', 0)
  	.merge(groups.select('circle'))
  		.attr('fill', d => colorScale(d.type))
  		.transition().duration(1000)
      .attr('r', d => radiusScale(d.type));
  
  groupsEnter.append('text')
  		// .attr('cx', xPosition)
  		// .attr('cy', height/2)
  	.merge(groups.select('text'))
      .text(d => d.type)
  		.attr('y', 50);
  
  groups.exit()
  	.transition().duration(1000)
  	.select('circle')
  		.attr('r', 0)
    .remove();
  
  groups.exit()
    .select('text').remove();
};
